==> business-behavior-monitor-sdk-1.0-sources.jar: plus/gaga/monitor/sdk/push/impl/RedisPush.java <==
package plus.gaga.monitor.sdk.push.impl;

import plus.gaga.monitor.sdk.model.LogMessage;
import plus.gaga.monitor.sdk.push.IPush;
import org.redisson.Redisson;
import org.redisson.api.RTopic;
import org.redisson.api.RedissonClient;
import org.redisson.codec.JsonJacksonCodec;
import org.redisson.config.Config;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class RedisPush implements IPush {

    private final Logger logger = LoggerFactory.getLogger(RedisPush.class);

    // Redisson 客户端
    private RedissonClient redissonClient;

    @Override
    public synchronized void open(String host, int port) {
        // 单例模式启动
        if (null != redissonClient && !redissonClient.isShutdown()) return;
        // 启动 Redis 服务
        Config config = new Config();
        config.setCodec(JsonJacksonCodec.INSTANCE);
        config.useSingleServer()
                .setAddress("redis://" + host + ":" + port)
                .setConnectionPoolSize(64)
                .setConnectionMinimumIdleSize(10)
                .setIdleConnectionTimeout(1000)
                .setConnectTimeout(1000)
                .setRetryAttempts(3)
                .setRetryInterval(1000)
                .setPingConnectionInterval(0)
                .setKeepAlive(true)
        ;

        this.redissonClient = Redisson.create(config);
    }

    @Override
    public void send(LogMessage logMessage) {
        try {
            RTopic topic = redissonClient.getTopic("busines-behavior-monitor-sdk-topic");
            topic.publish(logMessage);
        } catch (Exception e) {
            logger.error("警告：业务行为监控组件，推送日志消息失败", e);
        }
    }

}

==> business-behavior-monitor-sdk-1.1-sources.jar: plus/gaga/monitor/sdk/push/impl/RedisPush.java <==
package plus.gaga.monitor.sdk.push.impl;

import plus.gaga.monitor.sdk.model.LogMessage;
import plus.gaga.monitor.sdk.push.IPush;
import org.redisson.Redisson;
import org.redisson.api.RTopic;
import org.redisson.api.RedissonClient;
import org.redisson.codec.JsonJacksonCodec;
import org.redisson.config.Config;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class RedisPush implements IPush {

    private final Logger logger = LoggerFactory.getLogger(RedisPush.class);

    // Redisson 客户端
    private RedissonClient redissonClient;

    @Override
    public synchronized void open(String host, int port) {
        // 单例模式启动
        if (null != redissonClient && !redissonClient.isShutdown()) return;
        // 启动 Redis 服务
        Config config = new Config();
        config.setCodec(JsonJacksonCodec.INSTANCE);
        config.useSingleServer()
                .setAddress("redis://" + host + ":" + port)
                .setConnectionPoolSize(64)
                .setConnectionMinimumIdleSize(10)
                .setIdleConnectionTimeout(1000)
                .setConnectTimeout(1000)
                .setRetryAttempts(3)
                .setRetryInterval(1000)
                .setPingConnectionInterval(0)
                .setKeepAlive(true)
        ;

        logger.info("业务监控启动启动完成 By business-behavior-monitor-sdk xiaofuge");

        this.redissonClient = Redisson.create(config);
    }

    @Override
    public void send(LogMessage logMessage) {
        try {
            RTopic topic = redissonClient.getTopic("business-behavior-monitor-sdk-topic");
            topic.publish(logMessage);
        } catch (Exception e) {
            logger.error("警告：业务行为监控组件，推送日志消息失败", e);
        }
    }

}
